@@ -1,7 +1,8 @@
 # -*- coding: ascii -*-
 ###########################################################################
 # clive, command line video extraction utility.
-# Copyright 2007, 2008, 2009 Toni Gundogdu.
+#
+# Copyright 2009 Toni Gundogdu.
 #
 # This file is part of clive.
 #
@@ -34,13 +35,13 @@ sub parsePage {
 
     my %re = (
         id  => qr|/videofiles/(.*?)_|,
-        flv => qr|"flv", "(.*?)"|,
+        url => qr|"flv", "(.*?)"|,
     );
 
     my $tmp;
     if ( clive::Util::matchRegExps( \%re, \$tmp, $content ) == 0 ) {
         $$props->video_id( $tmp->{id} );
-        $$props->video_link( $tmp->{flv} );
+        $$props->video_link( $tmp->{url} );
         return (0);
     }
     return (1);
